reconfigure annotated tables - subsample predicted locations to 6-h interval, write to .csv and zip by campaign id

smru_write_csv(
  smru_ssm,
  fit,
  what,
  meta,
  program = "imos",
  proj = NULL,
  test = TRUE,
  path = NULL,
  dropIDs = NULL,
  suffix = "_nrt"
)

Arguments

smru_ssm

SSM-appended SMRU table file - output of append_ssm

fit

final aniMotum fit object

what

specify whether predicted or rerouted locations are to be used

meta

metadata

program

Determines structure of output metadata. The imos & atn programs have their own defined metadata structures, all other programs are treated as "Generic".

proj

the proj4string specified in the .JSON config file & used to project the location data prior to SSM fitting. It is passed in here to be added to the output metadata .CSV file

test

should variables be tested for standards compliance, default is TRUE. Standards compliance is specific to the program. Currently, only program = imos has defined variable standard against which output compliance is tested.

path

path to write .csv files

dropIDs

individual SMRU ids to be dropped

suffix

suffix to add to .csv files (_nrt, _dm, or _hist)