R/smru_write_csv.R
smru_write_csv.Rdreconfigure annotated tables - subsample predicted locations to 6-h interval, write to .csv and zip by campaign id
smru_write_csv(
smru_ssm,
fit,
what,
meta,
program = "imos",
proj = NULL,
test = TRUE,
path = NULL,
dropIDs = NULL,
suffix = "_nrt"
)SSM-appended SMRU table file - output of append_ssm
final aniMotum fit object
specify whether predicted or rerouted locations are to be used
metadata
Determines structure of output metadata. The imos & atn programs
have their own defined metadata structures, all other programs are treated as "Generic".
the proj4string specified in the .JSON config file & used to project the location data prior to SSM fitting. It is passed in here to be added to the output metadata .CSV file
should variables be tested for standards compliance, default is TRUE.
Standards compliance is specific to the program. Currently, only program = imos
has defined variable standard against which output compliance is tested.
path to write .csv files
individual SMRU ids to be dropped
suffix to add to .csv files (_nrt, _dm, or _hist)